@@ -62,7 +62,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:339  */
+#line 1 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:339  */
 
 /*
 **  Originally written by Steven M. Bellovin <smb@research.att.com> while
@@ -309,7 +309,7 @@ extern int yydebug;
 
 union YYSTYPE
 {
-#line 179 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:355  */
+#line 179 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:355  */
 
     time_t		Number;
     enum _MERIDIAN	Meridian;
@@ -1435,7 +1435,7 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 195 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 195 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyYear = 1970;
 	    yyMonth = 1;
@@ -1449,7 +1449,7 @@ yyreduce:
     break;
 
   case 5:
-#line 206 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 206 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyHaveTime++;
 	}
@@ -1457,7 +1457,7 @@ yyreduce:
     break;
 
   case 6:
-#line 209 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 209 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyHaveZone++;
 	}
@@ -1465,7 +1465,7 @@ yyreduce:
     break;
 
   case 7:
-#line 212 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 212 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyHaveDate++;
 	}
@@ -1473,7 +1473,7 @@ yyreduce:
     break;
 
   case 8:
-#line 215 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 215 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyHaveDay++;
 	}
@@ -1481,7 +1481,7 @@ yyreduce:
     break;
 
   case 9:
-#line 218 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 218 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyHaveRel++;
 	}
@@ -1489,7 +1489,7 @@ yyreduce:
     break;
 
   case 10:
-#line 223 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 223 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyHour = (yyvsp[-1].Number);
 	    yyMinutes = 0;
@@ -1500,7 +1500,7 @@ yyreduce:
     break;
 
   case 11:
-#line 229 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 229 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyHour = (yyvsp[-3].Number);
 	    yyMinutes = (yyvsp[-1].Number);
@@ -1511,7 +1511,7 @@ yyreduce:
     break;
 
   case 12:
-#line 235 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 235 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyHour = (yyvsp[-3].Number);
 	    yyMinutes = (yyvsp[-1].Number);
@@ -1523,7 +1523,7 @@ yyreduce:
     break;
 
   case 13:
-#line 242 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 242 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyHour = (yyvsp[-5].Number);
 	    yyMinutes = (yyvsp[-3].Number);
@@ -1534,7 +1534,7 @@ yyreduce:
     break;
 
   case 14:
-#line 248 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 248 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyHour = (yyvsp[-5].Number);
 	    yyMinutes = (yyvsp[-3].Number);
@@ -1547,7 +1547,7 @@ yyreduce:
     break;
 
   case 15:
-#line 258 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 258 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyTimezone = (yyvsp[0].Number);
 	    yyDSTmode = DSToff;
@@ -1556,7 +1556,7 @@ yyreduce:
     break;
 
   case 16:
-#line 262 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 262 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyTimezone = (yyvsp[0].Number);
 	    yyDSTmode = DSTon;
@@ -1565,7 +1565,7 @@ yyreduce:
     break;
 
   case 17:
-#line 267 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 267 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyTimezone = (yyvsp[-1].Number);
 	    yyDSTmode = DSTon;
@@ -1574,7 +1574,7 @@ yyreduce:
     break;
 
   case 18:
-#line 273 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 273 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyDayOrdinal = 1;
 	    yyDayNumber = (yyvsp[0].Number);
@@ -1583,7 +1583,7 @@ yyreduce:
     break;
 
   case 19:
-#line 277 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 277 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyDayOrdinal = 1;
 	    yyDayNumber = (yyvsp[-1].Number);
@@ -1592,7 +1592,7 @@ yyreduce:
     break;
 
   case 20:
-#line 281 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 281 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyDayOrdinal = (yyvsp[-1].Number);
 	    yyDayNumber = (yyvsp[0].Number);
@@ -1601,7 +1601,7 @@ yyreduce:
     break;
 
   case 21:
-#line 287 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 287 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyMonth = (yyvsp[-2].Number);
 	    yyDay = (yyvsp[0].Number);
@@ -1610,7 +1610,7 @@ yyreduce:
     break;
 
   case 22:
-#line 291 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 291 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyMonth = (yyvsp[-4].Number);
 	    yyDay = (yyvsp[-2].Number);
@@ -1620,7 +1620,7 @@ yyreduce:
     break;
 
   case 23:
-#line 296 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 296 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    /* ISO 8601 format.  yyyy-mm-dd.  */
 	    yyYear = (yyvsp[-2].Number);
@@ -1631,7 +1631,7 @@ yyreduce:
     break;
 
   case 24:
-#line 302 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 302 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    /* e.g. 17-JUN-1992.  */
 	    yyDay = (yyvsp[-2].Number);
@@ -1642,7 +1642,7 @@ yyreduce:
     break;
 
   case 25:
-#line 308 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 308 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyMonth = (yyvsp[-1].Number);
 	    yyDay = (yyvsp[0].Number);
@@ -1651,7 +1651,7 @@ yyreduce:
     break;
 
   case 26:
-#line 312 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 312 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyMonth = (yyvsp[-3].Number);
 	    yyDay = (yyvsp[-2].Number);
@@ -1661,7 +1661,7 @@ yyreduce:
     break;
 
   case 27:
-#line 317 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 317 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyMonth = (yyvsp[0].Number);
 	    yyDay = (yyvsp[-1].Number);
@@ -1670,7 +1670,7 @@ yyreduce:
     break;
 
   case 28:
-#line 321 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 321 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyMonth = (yyvsp[-1].Number);
 	    yyDay = (yyvsp[-2].Number);
@@ -1680,7 +1680,7 @@ yyreduce:
     break;
 
   case 29:
-#line 328 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 328 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyRelSeconds = -yyRelSeconds;
 	    yyRelMonth = -yyRelMonth;
@@ -1689,7 +1689,7 @@ yyreduce:
     break;
 
   case 31:
-#line 335 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 335 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyRelSeconds += (yyvsp[-1].Number) * (yyvsp[0].Number) * 60L;
 	}
@@ -1697,7 +1697,7 @@ yyreduce:
     break;
 
   case 32:
-#line 338 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 338 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyRelSeconds += (yyvsp[-1].Number) * (yyvsp[0].Number) * 60L;
 	}
@@ -1705,7 +1705,7 @@ yyreduce:
     break;
 
   case 33:
-#line 341 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 341 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyRelSeconds += (yyvsp[0].Number) * 60L;
 	}
@@ -1713,7 +1713,7 @@ yyreduce:
     break;
 
   case 34:
-#line 344 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 344 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyRelSeconds += (yyvsp[-1].Number);
 	}
@@ -1721,7 +1721,7 @@ yyreduce:
     break;
 
   case 35:
-#line 347 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 347 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyRelSeconds += (yyvsp[-1].Number);
 	}
@@ -1729,7 +1729,7 @@ yyreduce:
     break;
 
   case 36:
-#line 350 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 350 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyRelSeconds++;
 	}
@@ -1737,7 +1737,7 @@ yyreduce:
     break;
 
   case 37:
-#line 353 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 353 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyRelMonth += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
@@ -1745,7 +1745,7 @@ yyreduce:
     break;
 
   case 38:
-#line 356 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 356 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyRelMonth += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
@@ -1753,7 +1753,7 @@ yyreduce:
     break;
 
   case 39:
-#line 359 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 359 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    yyRelMonth += (yyvsp[0].Number);
 	}
@@ -1761,7 +1761,7 @@ yyreduce:
     break;
 
   case 40:
-#line 364 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 364 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    (yyval.Meridian) = MER24;
 	}
@@ -1769,7 +1769,7 @@ yyreduce:
     break;
 
   case 41:
-#line 367 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
+#line 367 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1646  */
     {
 	    (yyval.Meridian) = (yyvsp[0].Meridian);
 	}
@@ -2005,7 +2005,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 372 "/usr/src/ports/krb5/krb5-1.13.2-3.i686/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1906  */
+#line 372 "/usr/src/ports/krb5/krb5-1.13.2-4.x86_64/src/krb5-1.13.2/src/kadmin/cli/getdate.y" /* yacc.c:1906  */
 
 
 /* Month and day table. */
